spacepy.empiricals.getMPstandoff — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- empiricals - module with heliospheric empirical modules »

# spacepy.empiricals.getMPstandoff

`spacepy.empiricals.` `getMPstandoff`(ticks)

  Calculates the Shue et al. (1997) subsolar magnetopause radius

  Lets put the full reference here

  Parameters: | ticks : spacepy.time.Ticktock TickTock object of desired times (will be interpolated from hourly OMNI data) OR dictionary of form {‘P’: [], ‘Bz’: []} Where P is SW ram pressure [nPa] and Bz is IMF Bz (GSM) [nT]
  Returns: | out : float Magnetopause (sub-solar point) standoff distance [Re]

  Examples

      >>> import spacepy.time as spt
      >>> import spacepy.empiricals as emp
      >>> ticks = spt.tickrange('2002-01-01T12:00:00','2002-01-04T00:00:00',.25)
      >>> emp.ShueMP(ticks)
      array([ 10.57319537,  10.91327764,  10.75086873,  10.77577207,
           9.78180261,  11.0374474 ,  11.4065    ,  11.27555451,
          11.47988573,  11.8202582 ,  11.23834814])
      >>> data = {'P': [2,4], 'Bz': [-2.4, -2.4]}
      >>> emp.ShueMP(data)
      array([ 9.96096838,  8.96790412])

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- empiricals - module with heliospheric empirical modules »